# Databricks GenAI

Wrapper around dbutils & mcli

## Finetuning

See test notebook for manually testing & developer workflows inside databricks

Set the environment variable GENAI_LOCAL=true inside your python shell to test against Mosaic MAPI (requires normal MCLI setup)
